debug

package
v0.17.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 9, 2025 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

const DebugRoute = "debug"

Variables

This section is empty.

Functions

func Cargohome added in v0.15.0

func Cargohome(ctx context.Context, client gwclient.Client) (*gwclient.Result, error)

Cargohome outputs all the Cargo dependencies for the spec

func Gomods added in v0.3.0

func Gomods(ctx context.Context, client gwclient.Client) (*gwclient.Result, error)

Gomods outputs all the gomodule dependencies for the spec

func Handle added in v0.3.0

func Handle(ctx context.Context, client gwclient.Client) (*gwclient.Result, error)

func PatchedSources added in v0.13.0

func PatchedSources(ctx context.Context, client gwclient.Client) (*gwclient.Result, error)

Sources is a handler that outputs all the sources.

func Pip added in v0.16.0

func Pip(ctx context.Context, client gwclient.Client) (*gwclient.Result, error)

Pip outputs all the pip dependencies for the spec

func Resolve added in v0.3.0

func Resolve(ctx context.Context, client gwclient.Client) (*gwclient.Result, error)

Resolve is a handler that generates a resolved spec file with all the build args and variables expanded.

func Sources added in v0.3.0

func Sources(ctx context.Context, client gwclient.Client) (*gwclient.Result, error)

Sources is a handler that outputs all the sources.

Types

This section is empty.

Directories

Path Synopsis

Jump to