debug

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 23, 2024 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func HandleResolve

func HandleResolve(ctx context.Context, client gwclient.Client, spec *dalec.Spec) (gwclient.Reference, *image.Image, error)

HandleResolve is a handler that generates a resolved spec file with all the build args and variables expanded.

func HandleSources

func HandleSources(ctx context.Context, gwc client.Client, spec *dalec.Spec) (client.Reference, *image.Image, error)

HandleSources is a handler that outputs all the sources.

func RegisterHandlers

func RegisterHandlers()

Types

This section is empty.

Jump to