Documentation
¶
Index ¶
- func Build(topDir, workerImg llb.State, specPath string, opts ...llb.ConstraintsOpt) llb.State
- func SpecToBuildrootLLB(worker llb.State, spec *dalec.Spec, sOpt dalec.SourceOpts, targetKey string, ...) (llb.State, error)
- func ToSourcesLLB(worker llb.State, spec *dalec.Spec, sOpt dalec.SourceOpts, ...) ([]llb.State, error)
- func ToSpecLLB(spec *dalec.Spec, in llb.State, targetKey, dir string, ...) (llb.State, error)
- func ValidateSpec(spec *dalec.Spec) (out error)
- func WriteSpec(spec *dalec.Spec, target string, w io.Writer) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Build ¶
Builds an RPM and source RPM from a spec
`topDir` is the rpmbuild top directory which should contain the SOURCES and SPECS directories along with any other necessary files
`workerImg` is the image to use for the build It is expected to have rpmbuild and any other necessary build dependencies installed
`specPath` is the path to the spec file to build relative to `topDir`
func SpecToBuildrootLLB ¶
func ToSourcesLLB ¶
func ValidateSpec ¶
ValidateSpec makes sure all the necessary fields are present in the spec to make rpmbuild work This validation is specific to rpmbuild.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.